import Foundation

extension OSColor {
    var isLightColor: Bool {
        return self.luminance > 0.5
    }
    
    var luminance: Double {
        var r: CGFloat = 0
        var g: CGFloat = 0
        var b: CGFloat = 0
        var a: CGFloat = 0
        
        // getRed:green:blue:alpha requires sRGB space
        #if canImport(AppKit)
        guard let rgb = self.usingColorSpace(.sRGB) else { return 0 }
        #else
        let rgb = self
        #endif
        rgb.getRed(&r, green: &g, blue: &b, alpha: &a)
        return (0.299 * r) + (0.587 * g) + (0.114 * b)
    }

    func darken(by amount: CGFloat) -> OSColor {
        var h: CGFloat = 0, s: CGFloat = 0, b: CGFloat = 0, a: CGFloat = 0
        self.getHue(&h, saturation: &s, brightness: &b, alpha: &a)
        return OSColor(
            hue: h,
            saturation: s,
            brightness: min(b * (1 - amount), 1),
            alpha: a
        )
    }
}
